package org.springframework.boot.loader;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import org.springframework.boot.loader.JarLauncher;
import org.springframework.boot.loader.PropertiesLauncher;
import org.springframework.boot.loader.archive.Archive;
import org.springframework.boot.loader.archive.ExplodedArchive;
import org.springframework.boot.loader.archive.JarFileArchive;

class ClassPathArchives implements Iterable<Archive> {
  private final List<Archive> classPathArchives;
  
  private final List<JarFileArchive> jarFileArchives = new ArrayList<>();
  
  ClassPathArchives() throws Exception {
    this.classPathArchives = new ArrayList<>();
    for (String path : PropertiesLauncher.access$000(paramPropertiesLauncher)) {
      for (Archive archive : getClassPathArchives(path))
        addClassPathArchive(archive); 
    } 
    addNestedEntries();
  }
  
  private void addClassPathArchive(Archive archive) throws IOException {
    if (!(archive instanceof ExplodedArchive)) {
      this.classPathArchives.add(archive);
      return;
    } 
    this.classPathArchives.add(archive);
    this.classPathArchives.addAll(asList(archive.getNestedArchives(null, (Archive.EntryFilter)new PropertiesLauncher.ArchiveEntryFilter(null))));
  }
  
  private List<Archive> getClassPathArchives(String path) throws Exception {
    String root = PropertiesLauncher.access$300(PropertiesLauncher.this, PropertiesLauncher.access$200(PropertiesLauncher.this, path));
    List<Archive> lib = new ArrayList<>();
    File file = new File(root);
    if (!"/".equals(root)) {
      if (!isAbsolutePath(root))
        file = new File(PropertiesLauncher.access$400(PropertiesLauncher.this), root); 
      if (file.isDirectory()) {
        PropertiesLauncher.access$500(PropertiesLauncher.this, "Adding classpath entries from " + file);
        ExplodedArchive explodedArchive = new ExplodedArchive(file, false);
        lib.add(explodedArchive);
      } 
    } 
    Archive archive = getArchive(file);
    if (archive != null) {
      PropertiesLauncher.access$500(PropertiesLauncher.this, "Adding classpath entries from archive " + archive.getUrl() + root);
      lib.add(archive);
    } 
    List<Archive> nestedArchives = getNestedArchives(root);
    if (nestedArchives != null) {
      PropertiesLauncher.access$500(PropertiesLauncher.this, "Adding classpath entries from nested " + root);
      lib.addAll(nestedArchives);
    } 
    return lib;
  }
  
  private boolean isAbsolutePath(String root) {
    return (root.contains(":") || root.startsWith("/"));
  }
  
  private Archive getArchive(File file) throws IOException {
    if (isNestedArchivePath(file))
      return null; 
    String name = file.getName().toLowerCase(Locale.ENGLISH);
    if (name.endsWith(".jar") || name.endsWith(".zip"))
      return (Archive)getJarFileArchive(file); 
    return null;
  }
  
  private boolean isNestedArchivePath(File file) {
    return file.getPath().contains(PropertiesLauncher.access$600());
  }
  
  private List<Archive> getNestedArchives(String path) throws Exception {
    JarFileArchive jarFileArchive;
    Archive parent = PropertiesLauncher.access$700(PropertiesLauncher.this);
    String root = path;
    if ((!root.equals("/") && root.startsWith("/")) || parent
      .getUrl().toURI().equals(PropertiesLauncher.access$400(PropertiesLauncher.this).toURI()))
      return null; 
    int index = root.indexOf('!');
    if (index != -1) {
      File file = new File(PropertiesLauncher.access$400(PropertiesLauncher.this), root.substring(0, index));
      if (root.startsWith("jar:file:"))
        file = new File(root.substring("jar:file:".length(), index)); 
      jarFileArchive = getJarFileArchive(file);
      root = root.substring(index + 1);
      while (root.startsWith("/"))
        root = root.substring(1); 
    } 
    if (root.endsWith(".jar")) {
      File file = new File(PropertiesLauncher.access$400(PropertiesLauncher.this), root);
      if (file.exists()) {
        jarFileArchive = getJarFileArchive(file);
        root = "";
      } 
    } 
    if (root.equals("/") || root.equals("./") || root.equals("."))
      root = ""; 
    PropertiesLauncher.PrefixMatchingArchiveFilter prefixMatchingArchiveFilter = new PropertiesLauncher.PrefixMatchingArchiveFilter(root, null);
    List<Archive> archives = asList(jarFileArchive.getNestedArchives(null, (Archive.EntryFilter)prefixMatchingArchiveFilter));
    if ((root == null || root.isEmpty() || ".".equals(root)) && !path.endsWith(".jar") && jarFileArchive != 
      PropertiesLauncher.access$700(PropertiesLauncher.this))
      archives.add(jarFileArchive); 
    return archives;
  }
  
  private void addNestedEntries() {
    try {
      Iterator<Archive> archives = PropertiesLauncher.access$700(PropertiesLauncher.this).getNestedArchives(null, JarLauncher.NESTED_ARCHIVE_ENTRY_FILTER);
      while (archives.hasNext())
        this.classPathArchives.add(archives.next()); 
    } catch (IOException iOException) {}
  }
  
  private List<Archive> asList(Iterator<Archive> iterator) {
    List<Archive> list = new ArrayList<>();
    while (iterator.hasNext())
      list.add(iterator.next()); 
    return list;
  }
  
  private JarFileArchive getJarFileArchive(File file) throws IOException {
    JarFileArchive archive = new JarFileArchive(file);
    this.jarFileArchives.add(archive);
    return archive;
  }
  
  public Iterator<Archive> iterator() {
    return this.classPathArchives.iterator();
  }
  
  void close() throws IOException {
    for (JarFileArchive archive : this.jarFileArchives)
      archive.close(); 
  }
}
